@@ -1,4 +1,9 @@
 package Data::Embed::Reader;
+{
+  $Data::Embed::Reader::VERSION = '0.1';
+}
+
+# ABSTRACT: embed arbitrary data in a file - reader class
 
 use strict;
 use warnings;
@@ -9,14 +14,13 @@ use Storable qw< dclone >;
 use Data::Embed::File;
 use Data::Embed::Util qw< :constants unescape >;
 
-our $VERSION = '0.30'; # make indexer happy
 
 sub new {
    my $package = shift;
    my $input   = shift;
 
    # Undocumented, keep additional parameters around...
-   my %args = (scalar(@_) && ref($_[0])) ? %{$_[0]} : @_;
+   my %args    = (scalar(@_) && ref($_[0])) ? %{$_[0]} : @_;
    my $self = bless {args => \%args}, $package;
 
    # If a GLOB, just assign a default filename for logs and set
@@ -25,40 +29,37 @@ sub new {
       DEBUG $package, ': input is a GLOB';
       $self->{filename} = '<GLOB>';
       binmode $input, ":raw"
-        or LOGCROAK "binmode() to ':raw' failed";
-      $self->{fh} = $input;
-   } ## end if (ref($input) eq 'GLOB')
-   else {    # otherwise... it's a filename
-      DEBUG $package,
-        ': input is a file or other thing that can be open-ed';
+         or LOGCROAK "binmode() to ':raw' failed";
+      $self->{fh}       = $input;
+   }
+   else { # otherwise... it's a filename
+      DEBUG $package, ': input is a file or other thing that can be open-ed';
       $self->{filename} = $input;
-      open $self->{fh}, '<', $input
+      open $self->{fh}, '<:raw', $input
         or LOGCROAK "open('$input'): $OS_ERROR";
-      binmode $self->{fh}, ':raw';
-   } ## end else [ if (ref($input) eq 'GLOB')]
+   }
 
    return $self;
 } ## end sub new
 
+
 sub files {
    my $files = shift->_ensure_index()->{files};
    return wantarray() ? @$files : $files;
 }
 
-sub prefix {
-   return shift->_ensure_index()->{_prefix};
-}
 
 sub reset {
    my $self = shift;
    delete $self->{$_} for qw< files index >;
    return $self;
-}
+} ## end sub reset
+
 
 ######## PRIVATE METHODS ##############################################
 
 # Get the index of the embedded files as a L<Data::Embed::File> object.
-# You should normally not need this index, because it is parsed
+# You should normally not need this index, because it is parsed 
 sub _index { return shift->_ensure_index()->{_index}; }
 
 sub _ensure_index {
@@ -68,20 +69,13 @@ sub _ensure_index {
    if (!exists $self->{files}) {
       my $index = $self->_load_index()
         || {
-         _prefix => Data::Embed::File->new(
-            fh       => $self->{fh},
-            filename => $self->{filename},
-            name     => 'Data::Embed prefix data',
-            offset   => 0,
-            length   => scalar(__size($self->{fh})),
-         ),
-         files  => [],
+         files => [],
          _index => Data::Embed::File->new(
             fh       => $self->{fh},
             filename => $self->{filename},
             name     => 'Data::Embed index',
             length   => 0,
-            offset   => scalar(__size($self->{fh})),
+            offset   => scalar(-s $self->{fh}),
          ),
         };
       %$self = (%$self, %$index);
@@ -133,7 +127,7 @@ sub _load_index {
    # Now we established the full length of the data section, so it's
    # possible to adjust all offsets for all files (remember that the
    # files are assumed to be at the end of the embedding file)
-   my $full_length       = __size($fh);
+   my $full_length       = -s $fh;
    my $offset_correction = $full_length - $index_length - $data_length;
    for my $file (@files) {
       $file =
@@ -144,13 +138,6 @@ sub _load_index {
    # return the files in the index and the index itself, all as
    # Data::Embed::File objects for consistency
    return {
-      _prefix => Data::Embed::File->new(
-         fh       => $fh,
-         filename => $filename,
-         name     => 'Data::Embed prefix data',
-         length   => $offset_correction,
-         offset   => 0,
-      ),
       files  => \@files,
       _index => Data::Embed::File->new(
          fh       => $fh,
@@ -162,26 +149,12 @@ sub _load_index {
    };
 } ## end sub _load_index
 
-sub __size {
-   my $fh   = shift;
-   my $size = -s $fh;
-   if (!defined $size) {
-      DEBUG "getting size via seek";
-      my $current = tell $fh;
-      seek $fh, 0, SEEK_END;
-      $size = tell $fh;
-      DEBUG "size: $size";
-      seek $fh, $current, SEEK_SET;
-   } ## end if (!defined $size)
-   return $size;
-} ## end sub __size
-
 # read the last section of the file, looking for the index
 sub _read_index {
    my $self = shift;
    my ($fh, $filename) = @{$self}{qw< fh filename >};
    DEBUG "_read_index(): fh[$fh] filename[$filename]";
-   my $full_length = __size($fh);    # length of the whole stream/file
+   my $full_length = -s $fh;    # length of the whole stream/file
 
    # look for TERMINATOR at the very end of the file
    my $terminator = TERMINATOR;
@@ -268,3 +241,64 @@ sub _read {
 } ## end sub _read
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Data::Embed::Reader - embed arbitrary data in a file - reader class
+
+=head1 VERSION
+
+version 0.1
+
+=head1 METHODS
+
+=head2 new
+
+Constructor. Takes one positional parameter, that can be either
+a filename or a filehandle (in particular, a GLOB).
+
+If a filename is provided, is it opened for read in C<:raw> mode; an
+exception will be thrown if errors arise.
+
+If a filehandle is provided, it is expected to be seekable and will also
+be C<binmode>-d in C<:raw> mode; again, an exception is thrown in case
+of errors.
+
+=head2 B<< files >>
+
+Get the list of files embedded into the main file.
+
+In list context, it returns a list of L<Data::Embed::File> objects,
+each represeting a different embedded file.
+
+In scalar context, it returns an anonymous array with the list
+above.
+
+=head2 B<< reset >>
+
+reset the object's cached data, in particular the list of files. This
+might come handy in case you update the file and you want to re-read
+the index.
+
+=head1 AUTHOR
+
+Flavio Poletti <polettix@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2014 by Flavio Poletti <polettix@cpan.org>
+
+This module is free software.  You can redistribute it and/or
+modify it under the terms of the Artistic License 2.0.
+
+This program is distributed in the hope that it will be useful,
+but without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
+
+=cut
